# Quiz 🎯

## Create your quiz game faster in Python!

### Why?

To practice for exams, test your knowledge, and boost your memory!

## How?

1. **Import** this module into your script:

```
from quiz_game import start_quiz
```

2. **Add your questions and answers** in a dictionary:

```
start_quiz(
    {
        "question 1": "answer to question 1",
        "question 2": "answer to question 2",
        "question 3": "answer to question 3",
    }
)
```

3. **Run your script** and play the quiz!

You’ll see ✅ for correct answers and 💀 for wrong ones.
At the end, you’ll get your score, e.g. "2/3".
